## modelpruner - prune metabolic models coded in (SBML)

This is a port to Python and improvement of the network reduction
MATLAB code (CNAreduceMFNetwork.m) implemented in **CellNetAnalyzer** [1].

GLPK (GNU Linear Programming Kit) [2] is used as local solver to solve 
related FBA (flux balance analysis) [4] and 
FVA (flux variability analysis) [5] problems.

The network pruning method is based on **An algorithm for the reduction
of genome-scale metabolic network models to meaningful core models** [3].
This port does not implement the additional (optional) step of 
network compression, which compresses linear pathways to single reactions
and suppresses some biomass metabolites and transport reactions.

## Benefits of this port:

This package is based on exising CellNetAnalzyer MATLAB code, mainly functions 
in CNAreduceMFNetwork.m, with following enhancements:

- significant speedup (e.g. network reduction of genome-scale E. coli network
  30 h -> less than 1 h on a laptop)
- direct interface to SBML coded models via **sbmlxdf**
- use of open software
- modifications can be implemented easier in Python compared to MATLAB 
- SBML identifiers, annotations, gene-product-associations, genes and 
  groups carried over transparently from the full network to the pruned 
  network, making subsequent interaction with external databases easier
- protected reactions, metabolites, functions, flux bound overwrites can be 
  provided in an Excel spreadsheet, alternatively as a Python dict 

Code has been developped and validated on Apple MacBook Pro 2019.
  
Speed-up improvements mainly due to faster implementation of flux variability
function calls on glpk and using muliprocessing. Speed improvements could 
also be achieved by removing candidate reactions and blocked metabolites 
at each iteration step, i.e. continuously reducing the size of the model.

## install package:
```shell
$ pip3 install modelprune@git+https://gitlab.cs.uni-duesseldorf.de/schubert/modelprune.git
```

## Small Python example

```python 3
import modelpruner

full_sbml = 'sample_data/SBML_models/Deniz_model_fba.xml'
pruned_sbml = 'sample_data/SBML_models/Deniz_model_fba_reduced.xml'
protected_name = 'sample_data/data/Deniz_model_fba_nrp2.xlsx'

# load the original model
mp = modelpruner.ModelPruner(full_sbml, protected_name)

print('---- network reduction -----')
mp.prune()

# export pruned model in sbml format
mp.export_pruned_model(pruned_sbml)
print(mp.print_status())
```

## License

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>

[GPLv3](LICENSE.txt)


Peter Schubert, Computational Cell Biology, HHU Duesseldorf, July 2022

### References
[1] Kamp A, Thiele S, Haedicke O, Klamt S. (2017) Use of CellNetAnalyzer
in biotechnology and metabolic engineering. Journal of Biotechnolgy 261:
221-228. https://doi.org/10.1016/j.jbiotec.2017.05.001

[2] The GLPK package is part of the GNU Project released under the aegis of GNU.

[3] Erdrich P, Steuer R, Klamt S. (2015) An algorithm for the reduction
of genome-scale metabolic network models to meaningful core models.
BMC Syst Biol 9, 48. https://doi.org/10.1186/s12918-015-0191-x

[4] Fell, DA; Small, JR (1986). "Fat synthesis in adipose tissue. 
An examination of stoichiometric constraints". 
Biochem J. 238 (3): 781–786. doi:10.1042/bj2380781. PMC 1147204. PMID 3800960.

[5] Mahadevan, R., & Schilling, C. H. (2003). The effects of alternate optimal 
solutions in constraint-based genome-scale metabolic models. 
Metabolic Engineering, 5(4), 264–276. https://doi.org/10.1016/j.ymben.2003.09.002