# -*- coding: utf-8 -*-
import os
import re
from setuptools import setup, find_packages


setup_kwargs = {}

with open('README.md') as f:
    setup_kwargs['long_description'] = f.read()

# version from file
with open(os.path.join('modelpruner', '_version.py')) as f:
    mo = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                   f.read(), re.MULTILINE)
    if mo:
        setup_kwargs['version'] = mo.group(1)

setup(
    name='modelpruner',
    description='prune reactions in a metabolic SBML coded model',
    author='Peter Schubert',
    author_email='peter.schubert@hhu.de',
    url='https://gitlab.cs.uni-duesseldorf.de/schubert/networkred',
    project_urls={
        "Source Code": 'https://gitlab.cs.uni-duesseldorf.de/schubert/modelpruner',
        #"Documentation": 'https://sbmlxdf.readthedocs.io'
        },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
    ],
    license='GPLv3',
    long_description_content_type='text/markdown',
    packages=find_packages(exclude='docs'),
    install_requires=['pandas>=1.02.0',
                      'numpy>= 1.20.0',
                      'sbmlxdf>=0.2.7',
                      'swiglpk>=5.0.3',
                      'scipy>=1.8.1',
                      ],
    python_requires=">=3.7",
    keywords=['modeling', 'standardization', 'network reduction', 'SBML'],
    **setup_kwargs
)
